牯岭街少年杀人事件 (豆瓣)
Description: 牯岭街少年杀人事件电影简介和剧情介绍,牯岭街少年杀人事件影评、图片、预告片、影讯、论坛、在线购票
Keywords: 牯岭街少年杀人事件,牯嶺街少年殺人事件,牯岭街少年杀人事件影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.198豆瓣电影Top250

# 牯岭街少年杀人事件 牯嶺街少年殺人事件 (1991)

导演: 杨德昌
编剧: 杨德昌 / 赖铭堂 / 杨顺清 / 鸿鸿
主演: 张震 / 杨静怡 / 张国柱 / 王启赞 / 林鸿铭 / 金燕玲 / 王琄 / 张翰 / 姜秀琼 / 赖梵耘 / 柯宇纶 / 谭志刚 / 冯国强 / 陈湘琪 / 金士杰
类型: 剧情 / 犯罪
制片国家/地区: 中国台湾
语言: 汉语普通话 / 闽南语 / 上海话 / 粤语
上映日期: 1991-07-27(中国台湾)
片长: 237分钟(导演剪辑版)
又名: A Brighter Summer Day
IMDb: tt0101985
豆瓣评分
引用
8.9
276750人评价
5星
57.1%
4星
32.7%
3星
8.7%
2星
1.1%
1星
0.4%
好于 98% 犯罪片
好于 98% 剧情片
想看 看过
评价:
推荐

## 牯岭街少年杀人事件的剧情简介 · · · · · ·

结识小明（杨静怡）前，小四（张震）是典型的乖仔，是父母的希望和兄妹的骄傲（一家人指望他考上名牌大学将来提升全家的社会地位），他有一个喜欢摇滚乐的自称“小猫王（王启赞）”的好友，两人虽会去树林看人幽会，但过的是与周围诸多在“小公园”混的少年人完全两样的生活。
喜欢上小明后 ，小四便像跌进一个无底深渊，开始被外界的各种力量牵着鼻子走。新识仰慕对象honey（林鸿铭）意外身亡，一向敬重的父亲的自尊与精神因为某次事件严重受损，加上将一次次“欺骗玩弄”他感情的小明“看透”，血气方刚又有很强道德感的小四终于走上犯罪的道路，期望用自己的刀结束事件的根源。但小四不知的是，他眼中的根源只是这条食物链中微不足道的一环。 ©豆瓣

## 牯岭街少年杀人事件的演职员 · · · · · · ( 全部 55 )

- 杨德昌 导演
- 张震 演员
- 杨静怡 演员
- 张国柱 演员
- 王启赞 演员
- 林鸿铭 演员

## 牯岭街少年杀人事件的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1907 · 添加 )

## 牯岭街少年杀人事件的获奖情况 · · · · · · ( 全部 )

- 第28届台北金马影展
- 金马奖 最佳剧情片

- 第28届台北金马影展
- 金马奖 最佳导演(提名)
- 杨德昌

- 第4届东京国际电影节
- 主竞赛单元 最佳影片(提名)
- 杨德昌

## 喜欢这部电影的人也喜欢 · · · · · ·

  末路狂花

  杀人回忆

  上帝之城

  七宗罪

  出租车司机

  沉默的羔羊

  三块广告牌

  教父3

  心迷宫

  低俗小说

我要写短评

## 牯岭街少年杀人事件的短评 · · · · · · ( 全部 73671 条 )

热门 / 最新 / 好友

### 5069 有用 亚比煞 看过 2011-09-25 10:46:40

很多电影里都会杀人。只有在杨德昌的电影里，那不是杀人，那是整个世界的崩毁。他要你眼睁睁的看着，他用两个多小时创造的世界，在少年捅下去的那一刀里，灰飞烟灭。

### 1071 有用 小耳朵图吗 看过 2007-08-21 06:48:16

4个小时的片,中途睡着了

### 363 有用 nadja 看过 2006-02-04 21:04:30

没什么好看的,时间特长,很闷,还不是我喜欢的闷

### 3185 有用 黑胖砸儿 看过 2009-10-07 21:24:23

海那边六十年代的生活跟海这边八、九十年代差不太多，但tmd海南边的学生凭什么人手一双converse？凭tm什么？

### 3997 有用 袁牧 看过 2010-07-16 19:04:19

弱者送给弱者的一刀

> 更多短评 73671条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 牯岭街少年杀人事件的影评 · · · · · · ( 全部 1725 条 )

热门 / 最新 / 好友
林愈静 2008-08-10 21:39:46

## 我心目中最完美的电影

昨晚我又重看了一遍《牯岭街少年杀人事件》，这是第三次完整的看这部近四个小时的电影，这部电影几乎是我无法承受的生命之重---简单说，任何时候把这张碟片放入碟机时，我都感到异常庄重，也不是在看电影更像是在进行一场严肃的研讨会。 如果选出一个我最喜欢的导演，没有之一... (展开)
7968 473 564回应 收起
丁小云 2007-11-10 11:05:51

## 我只希望你能说一些粗俗的往事使我快乐

这篇影评可能有剧透

《牯岭街少年杀人事件》是台湾导演杨德昌1991年的作品。本片获1991年东京国际电影节评判团大奖及影评人大奖，法国三大洲影展最佳导演奖，新加坡影展最佳导演奖，台湾第28届金马奖最佳影片奖，第36届亚太影展最佳影片奖。 杨德昌，广东梅县人。1969年毕业于台北交大控制工程系，... (展开)
5028 229 286回应 收起
PingKe 2008-09-12 17:07:49

## 牯岭街教育诗

这篇影评可能有剧透

这是我看过的最牛的牯岭街文字。 牯岭街教育诗 　　 作者不详 　　 　　（1） 　　 　　我的家在牯岭街，我在这里工作和居住。我们这里以前出过事，我们的好兄弟茅武，在这里刺死了他的马子。 　　 　　后来，茅武的一个同级同学从牯岭街出去。杨德昌同学在美国学电脑，攻硕... (展开)
4209 79 189回应 收起
壹戈 2019-01-15 09:33:06 #《牯岭街少年杀人事件》有哪些方面值得关注？

## 从历史的角度理解《牯岭街少年杀人事件》

这篇影评可能有剧透

杨德昌导演是台湾新电影的领军人物，华语电影巨匠，他是一个现实主义的大师，人称“台湾社会的手术刀”，大部分电影都是，以影片同时代的台北都市为背景，但1991年的《牯岭街少年杀人事件》却是一个例外，讲的是1959年前后的故事。 《牯岭街少年杀人事件》是根据真实的案件改编... (展开)
1304 6 52回应 收起
吉米糕 2016-04-18 06:12:53

## 他们的世界，我们的忏悔。

如果青春是个梦境，那么我希望自己一梦不醒。 当牯岭街昏暗街灯下的一角，小四猛地将刀刺向小明的腹部时，他的青春在那一刻戛然而止了。 少女静静地滑落，倒在血泊中，少年却想努力扶起她，唤醒她，一如唤醒曾经稚嫩而倔强的相信，相信这个世界是朝着生命初始便认定了的那个方... (展开)
533 66 33回应 收起
Reader 2014-12-20 12:52:48

## 小四不住眷村

看了幾篇影評，或說本片主角小四一家是住眷村的外省人，或說小四這些眷村子弟組成了眷村幫派。都是明顯錯誤，應予辨正。 　　 在台灣，所謂眷村指的應該是部隊或單位建造，分配給中下級軍人或公務員和其眷屬居住（但不轉讓產權），屬於宿舍性質的平房式集合住宅所組成的聚... (展开)
384 13 75回应 收起
木卫二 2006-09-09 18:51:33

## 你的青春有几刀——从杨德昌到岩井俊二的青春片

http://www.cinepedia.cn/w/%E7%89%AF%E5%B2%AD%E8%A1%97%E5%B0%91%E5%B9%B4%E6%9D%80%E4%BA%BA%E4%BA%8B%E4%BB%B6 《牯岭街少年杀人事件》 影片条目（不断的完善中） 1.这世界不会为你而改变 《牯岭街少年杀人事件》结尾，猝不及防的，小四在拥紧小明时刺入了残酷的一... (展开)
367 88 42回应 收起
一路！ 2009-01-04 12:10:04

## 打KISS，泡MISS。。。

有人说，青春的躁动来源于荷尔蒙，迷茫的眼神，蒙胧的情愫，不安、犹豫、鲁莽、激烈...《牯岭街少年杀人案》，故事源自一个真实事件。再看这部老片子，心中不由泛起几分尘封的“荷尔蒙”的回忆... “打KISS，泡MISS！”正如电影的第一句台词，这就是青春的开始。金色朝阳下，... (展开)
320 16 21回应 收起
寂多蔓生 2012-07-01 18:25:53

## 台湾“联合报”当年关于《牯岭街少年杀人事件》真实版本的新闻报道

来源：网络 不良少年情杀命案少女移情别恋 可怜死于乱刀年仅十五六闯下塌天祸 本报讯 十五曰晚十时十分许，本市牯岭街七巷底，发生不良少年情杀案，现年十六岁的「璧玉帮」老么茅武，因醋海兴波竟持利刃将芳龄十五的少... (展开)
229 8 52回应 收起
培根悖论唠唠嗑 2019-06-19 13:54:51 #《牯岭街少年杀人事件》有哪些方面值得关注？

## 《牯岭街少年杀人事件》锋利如“刀” 杨德昌导演的巅峰之作

这篇影评可能有剧透

杨德昌的整个导演生涯，如果不算未完成的动画片《追风》的话，剩余的七又四分之一长片电影，无一例外的聚焦在台北市。前三部长片也就是“台北三部曲”北京是80年代的台湾，后三部则是“新台北三部曲”背景是90年代。 唯独《牯岭街少年杀人事件》是精准的定位在1959年，而且这部... (展开)
228 1 7回应 收起

> 更多影评 1725篇

添加新讨论

## 讨论区 · · · · · ·

这部电影就是垃圾垃圾垃圾垃圾垃圾垃圾垃圾垃圾 | 来自载货电梯驾驶员 | 23 回应 | 2022-11-22 23:23:19
问题 | 来自lrealllza |  | 2022-11-17 16:36:47
想请问为什么小四一直去打针？ | 来自aga四不象 | 7 回应 | 2022-11-17 01:56:31
一开始为什么小马要帮小四，难道因为喜欢？ | 来自风鬱曦 | 2 回应 | 2022-11-16 23:09:18
有没有和我一样觉得小明很好看的人 | 来自小鹿仙貝 | 59 回应 | 2022-11-16 01:54:46

> 去这部影片的讨论区（全部444条）

## 关于《牯岭街少年杀人事件》的问题 · · · · · · ( 全部77个 )

- 我想问的是这片画质真很差，话说有没有比较清楚的版本？ 23人回答
- 女主放到现在是不是就是传说中的小婊砸？ 24人回答

> 全部77个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 文艺女王必修课「华语篇」 (不良生)
- 电影学院本科生必看100部 (志国)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 台湾文艺电影 (L先生)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  1分钟前 想看
- Stone
  11分钟前 看过
- momo
  14分钟前 想看

380668人看过 / 382571人想看

订阅牯岭街少年杀人事件的评论:
feed: rss 2.0